import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Wavefront Cloud Integration for AppDynamics. This allows AppDynamics cloud integrations to be created,
 * updated, and deleted.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * const appDynamics = new wavefront.CloudIntegrationAppDynamics("app_dynamics", {
 *     name: "Test Integration",
 *     userName: "example",
 *     controllerName: "exampleController",
 *     encryptedPassword: "encryptedPassword",
 * });
 * ```
 *
 * ## Import
 *
 * AppDynamic Cloud Integrations can be imported by using the `id`, e.g.:
 *
 * ```sh
 * $ pulumi import wavefront:index/cloudIntegrationAppDynamics:CloudIntegrationAppDynamics app_dynamics a411c16b-3cf7-4f03-bf11-8ca05aab898d
 * ```
 */
export declare class CloudIntegrationAppDynamics extends pulumi.CustomResource {
    /**
     * Get an existing CloudIntegrationAppDynamics resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CloudIntegrationAppDynamicsState, opts?: pulumi.CustomResourceOptions): CloudIntegrationAppDynamics;
    /**
     * Returns true if the given object is an instance of CloudIntegrationAppDynamics.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CloudIntegrationAppDynamics;
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    readonly additionalTags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * List of regular expressions that an application name must match (case-insensitively)
     * in order to be ingested.
     */
    readonly appFilterRegexes: pulumi.Output<string[] | undefined>;
    /**
     * Name of the SaaS controller.
     */
    readonly controllerName: pulumi.Output<string>;
    /**
     * Boolean flag to control Application Infrastructure metric ingestion.
     */
    readonly enableAppInfraMetrics: pulumi.Output<boolean | undefined>;
    /**
     * Boolean flag to control Backend metric ingestion.
     */
    readonly enableBackendMetrics: pulumi.Output<boolean | undefined>;
    /**
     * Boolean flag to control Business Transaction metric ingestion.
     */
    readonly enableBusinessTrxMetrics: pulumi.Output<boolean | undefined>;
    /**
     * Boolean flag to control Error metric ingestion.
     */
    readonly enableErrorMetrics: pulumi.Output<boolean | undefined>;
    /**
     * Boolean flag to control Individual Node metric ingestion.
     */
    readonly enableIndividualNodeMetrics: pulumi.Output<boolean | undefined>;
    /**
     * Boolean flag to control Overall Performance metric ingestion.
     */
    readonly enableOverallPerfMetrics: pulumi.Output<boolean | undefined>;
    /**
     * Set this to `false` to get separate results for all values within the time range,
     * by default it is `true`.
     */
    readonly enableRollup: pulumi.Output<boolean | undefined>;
    /**
     * Boolean flag to control Service End point metric ingestion.
     */
    readonly enableServiceEndpointMetrics: pulumi.Output<boolean | undefined>;
    /**
     * Password for AppDynamics user.
     */
    readonly encryptedPassword: pulumi.Output<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    readonly forceSave: pulumi.Output<boolean | undefined>;
    /**
     * The human-readable name of this integration.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    readonly service: pulumi.Output<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    readonly serviceRefreshRateInMinutes: pulumi.Output<number | undefined>;
    /**
     * Username is a combination of userName and the account name.
     */
    readonly userName: pulumi.Output<string>;
    /**
     * Create a CloudIntegrationAppDynamics resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CloudIntegrationAppDynamicsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CloudIntegrationAppDynamics resources.
 */
export interface CloudIntegrationAppDynamicsState {
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    additionalTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * List of regular expressions that an application name must match (case-insensitively)
     * in order to be ingested.
     */
    appFilterRegexes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Name of the SaaS controller.
     */
    controllerName?: pulumi.Input<string>;
    /**
     * Boolean flag to control Application Infrastructure metric ingestion.
     */
    enableAppInfraMetrics?: pulumi.Input<boolean>;
    /**
     * Boolean flag to control Backend metric ingestion.
     */
    enableBackendMetrics?: pulumi.Input<boolean>;
    /**
     * Boolean flag to control Business Transaction metric ingestion.
     */
    enableBusinessTrxMetrics?: pulumi.Input<boolean>;
    /**
     * Boolean flag to control Error metric ingestion.
     */
    enableErrorMetrics?: pulumi.Input<boolean>;
    /**
     * Boolean flag to control Individual Node metric ingestion.
     */
    enableIndividualNodeMetrics?: pulumi.Input<boolean>;
    /**
     * Boolean flag to control Overall Performance metric ingestion.
     */
    enableOverallPerfMetrics?: pulumi.Input<boolean>;
    /**
     * Set this to `false` to get separate results for all values within the time range,
     * by default it is `true`.
     */
    enableRollup?: pulumi.Input<boolean>;
    /**
     * Boolean flag to control Service End point metric ingestion.
     */
    enableServiceEndpointMetrics?: pulumi.Input<boolean>;
    /**
     * Password for AppDynamics user.
     */
    encryptedPassword?: pulumi.Input<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    forceSave?: pulumi.Input<boolean>;
    /**
     * The human-readable name of this integration.
     */
    name?: pulumi.Input<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    service?: pulumi.Input<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    serviceRefreshRateInMinutes?: pulumi.Input<number>;
    /**
     * Username is a combination of userName and the account name.
     */
    userName?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a CloudIntegrationAppDynamics resource.
 */
export interface CloudIntegrationAppDynamicsArgs {
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    additionalTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * List of regular expressions that an application name must match (case-insensitively)
     * in order to be ingested.
     */
    appFilterRegexes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Name of the SaaS controller.
     */
    controllerName: pulumi.Input<string>;
    /**
     * Boolean flag to control Application Infrastructure metric ingestion.
     */
    enableAppInfraMetrics?: pulumi.Input<boolean>;
    /**
     * Boolean flag to control Backend metric ingestion.
     */
    enableBackendMetrics?: pulumi.Input<boolean>;
    /**
     * Boolean flag to control Business Transaction metric ingestion.
     */
    enableBusinessTrxMetrics?: pulumi.Input<boolean>;
    /**
     * Boolean flag to control Error metric ingestion.
     */
    enableErrorMetrics?: pulumi.Input<boolean>;
    /**
     * Boolean flag to control Individual Node metric ingestion.
     */
    enableIndividualNodeMetrics?: pulumi.Input<boolean>;
    /**
     * Boolean flag to control Overall Performance metric ingestion.
     */
    enableOverallPerfMetrics?: pulumi.Input<boolean>;
    /**
     * Set this to `false` to get separate results for all values within the time range,
     * by default it is `true`.
     */
    enableRollup?: pulumi.Input<boolean>;
    /**
     * Boolean flag to control Service End point metric ingestion.
     */
    enableServiceEndpointMetrics?: pulumi.Input<boolean>;
    /**
     * Password for AppDynamics user.
     */
    encryptedPassword: pulumi.Input<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    forceSave?: pulumi.Input<boolean>;
    /**
     * The human-readable name of this integration.
     */
    name?: pulumi.Input<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    service: pulumi.Input<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    serviceRefreshRateInMinutes?: pulumi.Input<number>;
    /**
     * Username is a combination of userName and the account name.
     */
    userName: pulumi.Input<string>;
}
