import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to get information about all Wavefront derived metrics.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the information about all derived metrics.
 * const example = wavefront.getDerivedMetrics({
 *     limit: 10,
 *     offset: 0,
 * });
 * ```
 */
export declare function getDerivedMetrics(args?: GetDerivedMetricsArgs, opts?: pulumi.InvokeOptions): Promise<GetDerivedMetricsResult>;
/**
 * A collection of arguments for invoking getDerivedMetrics.
 */
export interface GetDerivedMetricsArgs {
    /**
     * Limit is the maximum number of results to be returned. Defaults to 100.
     */
    limit?: number;
    /**
     * Offset is the offset from the first result to be returned. Defaults to 0.
     */
    offset?: number;
}
/**
 * A collection of values returned by getDerivedMetrics.
 */
export interface GetDerivedMetricsResult {
    /**
     * List of all derived metrics in Wavefront. For each derived metric you will see a list of attributes.
     */
    readonly derivedMetrics: outputs.GetDerivedMetricsDerivedMetric[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly limit?: number;
    readonly offset?: number;
}
/**
 * Use this data source to get information about all Wavefront derived metrics.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the information about all derived metrics.
 * const example = wavefront.getDerivedMetrics({
 *     limit: 10,
 *     offset: 0,
 * });
 * ```
 */
export declare function getDerivedMetricsOutput(args?: GetDerivedMetricsOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDerivedMetricsResult>;
/**
 * A collection of arguments for invoking getDerivedMetrics.
 */
export interface GetDerivedMetricsOutputArgs {
    /**
     * Limit is the maximum number of results to be returned. Defaults to 100.
     */
    limit?: pulumi.Input<number>;
    /**
     * Offset is the offset from the first result to be returned. Defaults to 0.
     */
    offset?: pulumi.Input<number>;
}
