import * as pulumi from "@pulumi/pulumi";
import * as outputs from "./types/output";
/**
 * Use this data source to get information about all Wavefront external links.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the information about all external links.
 * const example = wavefront.getExternalLinks({
 *     limit: 10,
 *     offset: 0,
 * });
 * ```
 */
export declare function getExternalLinks(args?: GetExternalLinksArgs, opts?: pulumi.InvokeOptions): Promise<GetExternalLinksResult>;
/**
 * A collection of arguments for invoking getExternalLinks.
 */
export interface GetExternalLinksArgs {
    /**
     * Limit is the maximum number of results to be returned. Defaults to 100.
     */
    limit?: number;
    /**
     * Offset is the offset from the first result to be returned. Defaults to 0.
     */
    offset?: number;
}
/**
 * A collection of values returned by getExternalLinks.
 */
export interface GetExternalLinksResult {
    /**
     * List of all external links in Wavefront. For each external link you will see a list of attributes.
     */
    readonly externalLinks: outputs.GetExternalLinksExternalLink[];
    /**
     * The provider-assigned unique ID for this managed resource.
     */
    readonly id: string;
    readonly limit?: number;
    readonly offset?: number;
}
/**
 * Use this data source to get information about all Wavefront external links.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * // Get the information about all external links.
 * const example = wavefront.getExternalLinks({
 *     limit: 10,
 *     offset: 0,
 * });
 * ```
 */
export declare function getExternalLinksOutput(args?: GetExternalLinksOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetExternalLinksResult>;
/**
 * A collection of arguments for invoking getExternalLinks.
 */
export interface GetExternalLinksOutputArgs {
    /**
     * Limit is the maximum number of results to be returned. Defaults to 100.
     */
    limit?: pulumi.Input<number>;
    /**
     * Offset is the offset from the first result to be returned. Defaults to 0.
     */
    offset?: pulumi.Input<number>;
}
