import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Wavefront Role Resource. This allows roles to be created, updated, and deleted.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * const role = new wavefront.Role("role", {name: "Test Role"});
 * ```
 *
 * ## Import
 *
 * Roles can be imported by using the `id`, e.g.:
 *
 * ```sh
 * $ pulumi import wavefront:index/role:Role some_role a411c16b-3cf7-4f03-bf11-8ca05aab898d
 * ```
 */
export declare class Role extends pulumi.CustomResource {
    /**
     * Get an existing Role resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RoleState, opts?: pulumi.CustomResourceOptions): Role;
    /**
     * Returns true if the given object is an instance of Role.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Role;
    /**
     * A list of user groups or accounts to assign to this role.
     */
    readonly assignees: pulumi.Output<string[] | undefined>;
    /**
     * A short description of the role.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The name of the role.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A list of permissions to assign to this role. Valid options are
     * `agentManagement`, `alertsManagement`, `dashboardManagement`, `embeddedCharts`, `eventsManagement`, `externalLinksManagement`,
     * `hostTagManagement`, `metricsManagement`, and `userManagement`.
     */
    readonly permissions: pulumi.Output<string[] | undefined>;
    /**
     * Create a Role resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: RoleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Role resources.
 */
export interface RoleState {
    /**
     * A list of user groups or accounts to assign to this role.
     */
    assignees?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A short description of the role.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the role.
     */
    name?: pulumi.Input<string>;
    /**
     * A list of permissions to assign to this role. Valid options are
     * `agentManagement`, `alertsManagement`, `dashboardManagement`, `embeddedCharts`, `eventsManagement`, `externalLinksManagement`,
     * `hostTagManagement`, `metricsManagement`, and `userManagement`.
     */
    permissions?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a Role resource.
 */
export interface RoleArgs {
    /**
     * A list of user groups or accounts to assign to this role.
     */
    assignees?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A short description of the role.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the role.
     */
    name?: pulumi.Input<string>;
    /**
     * A list of permissions to assign to this role. Valid options are
     * `agentManagement`, `alertsManagement`, `dashboardManagement`, `embeddedCharts`, `eventsManagement`, `externalLinksManagement`,
     * `hostTagManagement`, `metricsManagement`, and `userManagement`.
     */
    permissions?: pulumi.Input<pulumi.Input<string>[]>;
}
