import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Wavefront Service Account Resource. This allows service accounts to be created, updated, and deleted.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * const basic = new wavefront.ServiceAccount("basic", {
 *     identifier: "sa::tftesting",
 *     active: true,
 * });
 * ```
 *
 * ## Import
 *
 * Service accounts can be imported by using `identifier`, e.g.:
 *
 * ```sh
 * $ pulumi import wavefront:index/serviceAccount:ServiceAccount basic sa::tftesting
 * ```
 */
export declare class ServiceAccount extends pulumi.CustomResource {
    /**
     * Get an existing ServiceAccount resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: ServiceAccountState, opts?: pulumi.CustomResourceOptions): ServiceAccount;
    /**
     * Returns true if the given object is an instance of ServiceAccount.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceAccount;
    /**
     * Whether or not the service account is active.
     */
    readonly active: pulumi.Output<boolean | undefined>;
    /**
     * The description of the service account.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The unique identifier of the service account to create. Must have the prefix `sa::`.
     */
    readonly identifier: pulumi.Output<string>;
    /**
     * ID of ingestion policy.
     */
    readonly ingestionPolicy: pulumi.Output<string | undefined>;
    /**
     * List of permission to grant to this service account. Valid options are
     * `agentManagement`, `alertsManagement`, `dashboardManagement`, `embeddedCharts`, `eventsManagement`, `externalLinksManagement`,
     * `hostTagManagement`, `metricsManagement`, and `userManagement`.
     */
    readonly permissions: pulumi.Output<string[]>;
    /**
     * List of user groups for this service account.
     */
    readonly userGroups: pulumi.Output<string[]>;
    /**
     * Create a ServiceAccount resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ServiceAccountArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering ServiceAccount resources.
 */
export interface ServiceAccountState {
    /**
     * Whether or not the service account is active.
     */
    active?: pulumi.Input<boolean>;
    /**
     * The description of the service account.
     */
    description?: pulumi.Input<string>;
    /**
     * The unique identifier of the service account to create. Must have the prefix `sa::`.
     */
    identifier?: pulumi.Input<string>;
    /**
     * ID of ingestion policy.
     */
    ingestionPolicy?: pulumi.Input<string>;
    /**
     * List of permission to grant to this service account. Valid options are
     * `agentManagement`, `alertsManagement`, `dashboardManagement`, `embeddedCharts`, `eventsManagement`, `externalLinksManagement`,
     * `hostTagManagement`, `metricsManagement`, and `userManagement`.
     */
    permissions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * List of user groups for this service account.
     */
    userGroups?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a ServiceAccount resource.
 */
export interface ServiceAccountArgs {
    /**
     * Whether or not the service account is active.
     */
    active?: pulumi.Input<boolean>;
    /**
     * The description of the service account.
     */
    description?: pulumi.Input<string>;
    /**
     * The unique identifier of the service account to create. Must have the prefix `sa::`.
     */
    identifier: pulumi.Input<string>;
    /**
     * ID of ingestion policy.
     */
    ingestionPolicy?: pulumi.Input<string>;
    /**
     * List of permission to grant to this service account. Valid options are
     * `agentManagement`, `alertsManagement`, `dashboardManagement`, `embeddedCharts`, `eventsManagement`, `externalLinksManagement`,
     * `hostTagManagement`, `metricsManagement`, and `userManagement`.
     */
    permissions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * List of user groups for this service account.
     */
    userGroups?: pulumi.Input<pulumi.Input<string>[]>;
}
