import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Wavefront User Resource. This allows user accounts to be created, updated, and deleted.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * const basic = new wavefront.User("basic", {email: "test+tftesting@example.com"});
 * ```
 *
 * ## Import
 *
 * Users can be imported by using the `id`, e.g.:
 *
 * ```sh
 * $ pulumi import wavefront:index/user:User some_user test@example.com
 * ```
 */
export declare class User extends pulumi.CustomResource {
    /**
     * Get an existing User resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: UserState, opts?: pulumi.CustomResourceOptions): User;
    /**
     * Returns true if the given object is an instance of User.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is User;
    /**
     * The customer the user is associated with.
     */
    readonly customer: pulumi.Output<string>;
    /**
     * The unique identifier of the user account to create. Must be a valid email address.
     */
    readonly email: pulumi.Output<string>;
    /**
     * List of permission to grant to this user. Valid options are
     * `agentManagement`, `alertsManagement`, `dashboardManagement`, `embeddedCharts`, `eventsManagement`, `externalLinksManagement`,
     * `hostTagManagement`, `metricsManagement`, and `userManagement`.
     */
    readonly permissions: pulumi.Output<string[]>;
    /**
     * List of user groups to this user.
     */
    readonly userGroups: pulumi.Output<string[]>;
    /**
     * Create a User resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: UserArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering User resources.
 */
export interface UserState {
    /**
     * The customer the user is associated with.
     */
    customer?: pulumi.Input<string>;
    /**
     * The unique identifier of the user account to create. Must be a valid email address.
     */
    email?: pulumi.Input<string>;
    /**
     * List of permission to grant to this user. Valid options are
     * `agentManagement`, `alertsManagement`, `dashboardManagement`, `embeddedCharts`, `eventsManagement`, `externalLinksManagement`,
     * `hostTagManagement`, `metricsManagement`, and `userManagement`.
     */
    permissions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * List of user groups to this user.
     */
    userGroups?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The set of arguments for constructing a User resource.
 */
export interface UserArgs {
    /**
     * The customer the user is associated with.
     */
    customer?: pulumi.Input<string>;
    /**
     * The unique identifier of the user account to create. Must be a valid email address.
     */
    email: pulumi.Input<string>;
    /**
     * List of permission to grant to this user. Valid options are
     * `agentManagement`, `alertsManagement`, `dashboardManagement`, `embeddedCharts`, `eventsManagement`, `externalLinksManagement`,
     * `hostTagManagement`, `metricsManagement`, and `userManagement`.
     */
    permissions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * List of user groups to this user.
     */
    userGroups?: pulumi.Input<pulumi.Input<string>[]>;
}
